@@ -26,7 +26,7 @@ from negotiator_common import NegotiatorInterface
 from negotiator_common.config import CHANNELS_DIRECTORY, GUEST_TO_HOST_CHANNEL_NAME, HOST_TO_GUEST_CHANNEL_NAME
 
 # Semi-standard module versioning.
-__version__ = '0.5'
+__version__ = '0.5.1'
 
 # Initialize a logger for this module.
 logger = logging.getLogger(__name__)
@@ -76,7 +76,12 @@ class HostDaemon(object):
 
 class AutomaticGuestChannel(multiprocessing.Process):
 
-    """Thin wrapper for :py:class:`GuestChannel` that puts it in a separate process."""
+    """
+    Thin wrapper for :py:class:`GuestChannel` that puts it in a separate process.
+
+    Uses :py:class:`multiprocessing.Process` to isolate guest channels in
+    separate processes.
+    """
 
     def __init__(self, *args, **kw):
         """
@@ -100,12 +105,8 @@ class GuestChannel(NegotiatorInterface):
     """
     The host side of the channel connecting KVM/QEMU hosts and guests.
 
-    The documentation of this class defines no public methods although
-    :py:class:`GuestChannel` is the external API of the negotiator project. The
-    reason for this is that calls to unknown :py:class:`GuestChannel` methods
-    are automatically relayed to the remote side running on a KVM/QEMU guest.
-    For this reason you should refer to the public methods implemented by the
-    :py:class:`.GuestAgent` class.
+    See also :py:class:`AutomaticGuestChannel` which wraps
+    :py:class:`GuestChannel` and puts it in its own process.
     """
 
     def __init__(self, guest_name, unix_socket=None):
@@ -115,8 +116,6 @@ class GuestChannel(NegotiatorInterface):
         :param guest_name: The name of the guest to connect to (a string).
         :param unix_socket: The absolute pathname of the UNIX socket that we
                             should connect to (a string, optional).
-        :raises: :py:exc:`exceptions.ValueError` when neither ``guest_name``
-                 nor ``unix_socket`` is given.
         """
         self.guest_name = guest_name
         # Figure out the absolute pathname of the UNIX socket?
@@ -134,7 +133,14 @@ class GuestChannel(NegotiatorInterface):
                                            label="UNIX socket %s" % unix_socket)
 
     def prepare_environment(self):
-        """Prepare environment variables for command execution."""
+        """
+        Prepare environment variables for command execution on KVM/QEMU hosts.
+
+        The following environment variables are currently exposed to commands:
+
+        ``$NEGOTIATOR_GUEST``
+          The name of the KVM/QEMU guest that invoked the command.
+        """
         os.environ['NEGOTIATOR_GUEST'] = self.guest_name
 
 
